## Topsis 
## A Multi-Criteria Decision Analysis Method

**Submitted By** - Armaan Bhardwaj  

**Roll No.** - 101903292 

**Group** - 3COE11


It is a Technique for Order Preference by Similarity to Ideal Solution (TOPSIS) came in the 1980s as a multi-criteria-based decision-making method. TOPSIS chooses the alternative of shortest the Euclidean distance from the ideal solution and greatest distance from the negative ideal solution. 

## Installation
This package requires pandas to be pre-installed and python to run.
Install the dependencies and devDependencies and start the server.
 **To Install and run in cmd line:**
```sh
pip install Topsis-Armaan-101903292
python
import Topsis_Armaan_101903292
Topsis_Armaan_101903292.topsis_cal(Input_File_Name.csv,"1,1,1,1 ...","+,-,+,- ...","resultfile.csv") 
```
##Project description
This package is implementation of topsis technique of multi-criteria decision analysis. This package will accept three parameters:

data.csv //file which contains the models and parameters
string of weights separated by commas(,)
string of requirements (+/-) separated by commas(,) // important install pandas,sys,operator and math libraries before installing this // You can install this package using following command pip install Topsis_Armaan_101903292

##License
© 2022 Armaan Bhardwaj

This repository is licensed under the MIT license. See LICENSE for details.